<?php
namespace Elementor\Core\Common\Modules\Finder\Categories;

use Elementor\Core\Common\Modules\Finder\Base_Category;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Site Category
 *
 * Provides general site items.
 */
class Site extends Base_Category {

	/**
	 * Get title.
	 *
	 * @since 2.3.0
	 * @access public
	 *
	 * @return string
	 */
	public function get_title() {
		return esc_html__( '站点', 'elementor' );
	}

	public function get_id() {
		return 'site';
	}

	/**
	 * Get category items.
	 *
	 * @since 2.3.0
	 * @access public
	 *
	 * @param array $options
	 *
	 * @return array
	 */
	public function get_category_items( array $options = [] ) {
		return [
			'homepage' => [
				'title' => esc_html__( '首页', 'elementor' ),
				'url' => home_url(),
				'icon' => 'home-heart',
				'keywords' => [ 'home', 'page' ],
			],
			'gechiui-dashboard' => [
				'title' => esc_html__( '仪表盘', 'elementor' ),
				'icon' => 'dashboard',
				'url' => admin_url(),
				'keywords' => [ 'dashboard', 'gechiui' ],
			],
			'gechiui-menus' => [
				'title' => esc_html__( '菜单', 'elementor' ),
				'icon' => 'gechiui',
				'url' => admin_url( 'nav-menus.php' ),
				'keywords' => [ 'menu', 'gechiui' ],
			],
			'gechiui-themes' => [
				'title' => esc_html__( '主题', 'elementor' ),
				'icon' => 'gechiui',
				'url' => admin_url( 'themes.php' ),
				'keywords' => [ 'themes', 'gechiui' ],
			],
			'gechiui-customizer' => [
				'title' => esc_html__( '自定义', 'elementor' ),
				'icon' => 'gechiui',
				'url' => admin_url( 'customize.php' ),
				'keywords' => [ 'customizer', 'gechiui' ],
			],
			'gechiui-plugins' => [
				'title' => esc_html__( '插件', 'elementor' ),
				'icon' => 'gechiui',
				'url' => admin_url( 'plugins.php' ),
				'keywords' => [ 'plugins', 'gechiui' ],
			],
			'gechiui-users' => [
				'title' => esc_html__( '用户', 'elementor' ),
				'icon' => 'gechiui',
				'url' => admin_url( 'users.php' ),
				'keywords' => [ 'users', 'profile', 'gechiui' ],
			],
		];
	}
}
