<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor GeChiUI widgets manager.
 *
 * Elementor GeChiUI widgets manager handler class is responsible for
 * registering and initializing all the supported controls, both regular
 * controls and the group controls.
 *
 * @since 1.5.0
 */
class GeChiUI_Widgets_Manager {

	/**
	 * GeChiUI widgets manager constructor.
	 *
	 * Initializing the GeChiUI widgets manager in Elementor editor.
	 *
	 * @since 1.5.0
	 * @access public
	 */
	public function __construct() {
		if ( version_compare( get_bloginfo( 'version' ), '4.8', '<' ) ) {
			return;
		}

		add_action( 'elementor/editor/before_enqueue_scripts', [ $this, 'before_enqueue_scripts' ] );
		add_action( 'elementor/editor/footer', [ $this, 'footer' ] );
	}

	/**
	 * Before enqueue scripts.
	 *
	 * Prints custom scripts required to run GeChiUI widgets in Elementor
	 * editor.
	 *
	 * Fired by `elementor/editor/before_enqueue_scripts` action.
	 *
	 * @since 1.5.0
	 * @access public
	 */
	public function before_enqueue_scripts() {
		global $gc_scripts;

		$suffix = Utils::is_script_debug() ? '' : '.min';

		// TODO: after GC >= 4.9 - it's no needed, Keep for Backward compatibility.
		$gc_scripts->add( 'media-widgets', "/gc-admin/js/widgets/media-widgets$suffix.js", array( 'jquery', 'media-models', 'media-views' ) );
		$gc_scripts->add_inline_script( 'media-widgets', 'gc.mediaWidgets.init();', 'after' );

		$gc_scripts->add( 'media-audio-widget', "/gc-admin/js/widgets/media-audio-widget$suffix.js", array( 'media-widgets', 'media-audiovideo' ) );
		$gc_scripts->add( 'media-image-widget', "/gc-admin/js/widgets/media-image-widget$suffix.js", array( 'media-widgets' ) );
		$gc_scripts->add( 'media-video-widget', "/gc-admin/js/widgets/media-video-widget$suffix.js", array( 'media-widgets', 'media-audiovideo' ) );
		$gc_scripts->add( 'text-widgets', "/gc-admin/js/widgets/text-widgets$suffix.js", array( 'jquery', 'editor', 'gc-util' ) );
		$gc_scripts->add_inline_script( 'text-widgets', 'gc.textWidgets.init();', 'after' );

		gc_enqueue_style( 'widgets' );
		gc_enqueue_style( 'media-views' );
		// End TODO.

		// Don't enqueue `code-editor` for GC Custom HTML widget.
		gc_get_current_user()->syntax_highlighting = 'false';

		/** This action is documented in gc-admin/admin-header.php */
		do_action( 'admin_print_scripts-widgets.php' );
	}

	/**
	 * GeChiUI widgets footer.
	 *
	 * Prints GeChiUI widgets scripts in Elementor editor footer.
	 *
	 * Fired by `elementor/editor/footer` action.
	 *
	 * @since 1.5.0
	 * @access public
	 */
	public function footer() {
		/** This action is documented in gc-admin/admin-footer.php */
		do_action( 'admin_footer-widgets.php' );
	}
}
